@@ -129,4 +129,7 @@ def getUid(name):
 def searchProblem(keyword,page,diffi=0):
     r=requests.get('https://www.luogu.com.cn/problem/list?keyword='+keyword+('&difficulty='+str(diffi) if diffi!=-1 else '')+'&page='+str(page)+'&_contentOnly=1',headers=headers)
     return r.json()['currentData']
-    
\ No newline at end of file
+    
+def getContestList(page):
+    r=requests.get('https://www.luogu.com.cn/contest/list?page='+str(page)+'&_contentOnly=1',headers=headers)
+    return r.json()['currentData']['contests']
\ No newline at end of file
